@@ -57,12 +57,15 @@ class Aggregator:
                 limit=limit)
             queryset = queryset.filter(top_groups_filter)
 
+        if len(queryset) == 0:
+            return []
+
         queryset = queryset.values(*group_by)
         queryset = queryset.annotate(**annotations)
         if order_by and len(order_by) > 0:
             queryset = queryset.order_by(*order_by)
 
-        if not limit_show_other:
+        if not limit or not limit_show_other:
             return list(queryset)
 
         aggregation_without_top = self.get_aggregation_without_top(
