@@ -4,7 +4,8 @@ from parameterized import parameterized
 from .models import TestCaseModel
 from .fixtures import RECORDS
 from .test_data import ANNOTATIONS_TESTING
-from .test_data import GROUP_TESTING
+from .test_data import SORTED_GROUPS_TESTING
+from .test_data import UNSORTED_GROUPS_TESTING
 
 
 class AggregationTests(APITestCase):
@@ -20,20 +21,18 @@ class AggregationTests(APITestCase):
         response = self.client.get(self.URL, query, format="json")
         self.assertEqual(response.status_code, 200,
                          msg=f"Failed on: {query}"
-                             f"\nResponse: {response.data}"
-                             f"\nExpected: {expected_response}")
+                             f"\nResponse: {response.data}")
         self.assertEqual(response.data, expected_response,
                          msg=f"Failed on: {query}"
                              f"\nResponse: {response.data}"
                              f"\nExpected: {expected_response}")
 
-    @parameterized.expand(GROUP_TESTING)
-    def test_group_by_fields(self, query, expected_response):
+    @parameterized.expand(UNSORTED_GROUPS_TESTING)
+    def test_group_by(self, query, expected_response):
         response = self.client.get(self.URL, query, format="json")
         self.assertEqual(response.status_code, 200,
                          msg=f"Failed on: {query}"
-                             f"\nResponse: {response.data}"
-                             f"\nExpected: {expected_response}")
+                             f"\nResponse: {response.data}")
         self.assertEqual(len(response.data), len(expected_response),
                          msg=f"Failed on: {query}"
                              f"\nResponse: {response.data}"
@@ -43,3 +42,18 @@ class AggregationTests(APITestCase):
                           msg=f"Failed on: {query}"
                               f"\nResponse: {response.data}"
                               f"\nExpected: {expected_response}")
+
+    @parameterized.expand(SORTED_GROUPS_TESTING)
+    def test_group_by_fields(self, query, expected_response):
+        response = self.client.get(self.URL, query, format="json")
+        self.assertEqual(response.status_code, 200,
+                         msg=f"Failed on: {query}"
+                             f"\nResponse: {response.data}")
+        self.assertEqual(len(response.data), len(expected_response),
+                         msg=f"Failed on: {query}"
+                             f"\nResponse: {response.data}"
+                             f"\nExpected: {expected_response}")
+        self.assertListEqual(response.data, expected_response,
+                             msg=f"Failed on: {query}"
+                                 f"\nResponse: {response.data}"
+                                 f"\nExpected: {expected_response}")
